pub struct Props<T>{
pub items: Rc<Vec<T>>,
pub row_height: f64,
pub class: Classes,
}Expand description
VirtualScroller properties
Fields
items: Rc<Vec<T>>Full list of items. This is within an Rc as the assumption is the list will be large and so cloning it would be expensive.
row_height: f64Height of each item in pixels.
class: ClassesClass(es) to apply to the root container